#!/usr/bin/env python

import os
import re
import sys
import time

MAX_DAYS_FOR_FULL_BACKUP = 60
MAX_DAYS_FOR_INCREMENTAL_BACKUP = 7

def get_most_recent_job_ids(all_jobs, _wanted_job_level):
    # (job_name, job_id)
    # e.g. name.job1, name.job2 etc.
    latest_jobs = {}

    max_days_for_job = -1
    if _wanted_job_level == 'incremental':
        wanted_job_level = 'I'
        max_days_for_job = MAX_DAYS_FOR_INCREMENTAL_BACKUP
    else:
        wanted_job_level = 'F'
        max_days_for_job = MAX_DAYS_FOR_FULL_BACKUP

    for line in all_jobs[7:]:
        if line[0].strip() == '|':
            splits = line[1:].split('|')

 
	    job_id = splits[0].strip().replace(',', '')
	    job_name = splits[1].strip()
            job_startdate = splits[2].strip()
            job_type = splits[3]
            job_level = splits[4].strip()
            job_files = splits[5].strip()
            job_status = splits[7]

            # if job type is B - backup and has status T - terminated and some files were backuped
            if 'B' in job_type and 'T' in job_status and job_files != '0':
                if job_level == wanted_job_level:
                    latest_jobs[job_name] = job_id
    
    return latest_jobs.values()

end_date_regex = re.compile('\\bendtime: [\\d\\-: ]*')
def get_job_endtime(job):
    """ Parses endtime from job info if the job has finished and returns it,
    None otherwise.
    """
    result = end_date_regex.findall(job)
    if len(result) > 0:
        return result[0].replace('endtime: ', '')

    # job hasn't finished yet
    return None

def get_most_recent_job_date(ids):
    """ Returns the date of the most recent job from a list of job ids
    """
    dates = {}
    for i in ids:
        job = os.popen('echo \"llist jobid={}\"|bconsole'.format(i), 'r').read()
        date = get_job_endtime(job)
        if date is None:
            continue

        dates[time.strptime(date, "%Y-%m-%d %H:%M:%S")] = date
    most_recent = max(dates.keys())

    return dates[most_recent]

def date_is_older_than(job_date_string, days):
    """ Checks if the job_date_string is older than 'days' days
    and returns true if it is, false otherwise.
    """
    job_date = time.strptime(job_date_string, "%Y-%m-%d %H:%M:%S")
    days_ago = time.gmtime(time.time() - 60*60*24*days)
    return job_date < days_ago

usage_string = "Usage: bacula_checkuser <user> <backup-type>"

def main():
    if len(sys.argv) != 3:
        print(usage_string)
        sys.exit(1)

    backup_level = sys.argv[2]
    if backup_level not in ['incremental', 'full']:
        print(usage_string)
        print("<backup-type> must be either 'incremental' or 'full'")
        sys.exit(1)


    client_name = sys.argv[1]

    all_client_jobs = os.popen('echo \"list jobs client={}\"|bconsole'.format(client_name), 'r').readlines()

    job_ids = get_most_recent_job_ids(all_client_jobs, backup_level)
    
    most_recent_job_date = get_most_recent_job_date(job_ids)

    print("{}".format(most_recent_job_date))

if __name__ == '__main__':
    main()

